﻿using igGridRunTimeCreate.Models;
using Infragistics.Web.Mvc;
using Infragistics.Web.Mvc.TagHelpers.Grids.Grid.Features.Updating;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Routing;
using System.Collections;
using System.Diagnostics;
using System.Text.Json;

namespace igGridRunTimeCreate.Controllers
{
    public class HomeController : Controller
    {
        public IActionResult Index()
        {
            GridModel gridModel = new GridModel();
            gridModel.ID = "gridModel";
            gridModel.AutoGenerateColumns = false;
            gridModel.AutoGenerateLayouts = false;
            gridModel.PrimaryKey = "ID";
            gridModel.Width = "100%";
            gridModel.AutoCommit = true;

            gridModel.Columns = new List<GridColumn>();
            gridModel.Columns.Add(new GridColumn() { HeaderText = "ID", Key = "ID", DataType = "number" });
            gridModel.Columns.Add(new GridColumn() { HeaderText = "Name", Key = "Name", DataType = "string" });
            gridModel.Columns.Add(new GridColumn() { HeaderText = "Job", Key = "Job", DataType = "string" });
            gridModel.Columns.Add(new GridColumn() { HeaderText = "Country", Key = "Country", DataType = "string" });

            gridModel.DataSource = GetCustomers().AsQueryable();

            gridModel.Features.Add(new GridUpdating()
            {
                ColumnSettings = new List<ColumnUpdatingSetting>() {
                    new ColumnUpdatingSetting() { ColumnKey = "Country", EditorType = ColumnEditorType.Combo, ComboEditorOptions = { DataSource = GetCountries(), TextKey = "Value", ValueKey = "Value" } },
                    new ColumnUpdatingSetting() { ColumnKey = "Job", EditorType = ColumnEditorType.Combo, ComboEditorOptions  = { DataSource = GetJobs(), TextKey = "Value", ValueKey = "Value" } }
                }
            });

            gridModel.Features.Add(new GridFiltering() { Type = OpType.Local, Inherit = true, Persist = false });
            gridModel.Features.Add(new GridSorting() { Type = OpType.Local, Inherit = true, Persist = false });

            return View(gridModel);
        }

        public CustomersViewModel GetModel()
        {
            var viewModel = new CustomersViewModel
            {
                //IEnumerable of Customer Objects
                Customers = GetCustomers(),
                Countries = GetCountries(),
                Jobs = GetJobs(),
            };

            return viewModel;
        }

        private IEnumerable<Customer> GetCustomers()
        {
            return new List<Customer>
            {
                new Customer { ID=1, Name="John Smith", Job="Software Developer", Country="Bulgaria" },
                new Customer { ID=2, Name="Bob Richards", Job="Lawer", Country="France" },
                new Customer { ID=3, Name="Marge Wright", Job="Doctor", Country="Germany" },
                new Customer { ID=4, Name="Dwight Long", Job="Dealer", Country="Spain" },
                new Customer { ID=5, Name="Amy Grant", Job="Teacher", Country="Bulgaria" },
                new Customer { ID=6, Name="Jon Terry", Job="Footballer", Country="UK" },
            };
        }

        public IQueryable<Country> GetCountries()
        {
            IQueryable<Country> data;
            IEnumerable<Country> temp = new List<Country>
            {
                new Country { Key="1", Value="Bulgaria"},
                new Country { Key="2", Value="USA"},
                new Country { Key="3", Value="Germany"},
                new Country { Key="4", Value="Spain"},
                new Country { Key="5", Value="UK"},
                new Country { Key="6", Value="France"},
            };
            data = temp.AsQueryable();

            return data;
        }

        public IQueryable<Job> GetJobs()
        {
            IQueryable<Job> data;
            IEnumerable<Job> temp = new List<Job>
            {
                new Job { Key="1", Value="Software Developer"},
                new Job { Key="2", Value="Lawer"},
                new Job { Key="3", Value="Doctor"},
                new Job { Key="4", Value="Dealer"},
                new Job { Key="5", Value="Teacher"},
                new Job { Key="6", Value="Housekeepr"},
                new Job { Key="7", Value="Worker"},
                new Job { Key="8", Value="Footballer"},
            };
            data = temp.AsQueryable();

            return data;
        }
    }
}